@@ -9,6 +9,8 @@ def normalize_path(path):
     if path:
         return os.path.abspath(os.path.expanduser(os.path.expandvars(path)))
 
+    return None
+
 
 def to_bool(string):
     return bool(strtobool(str(string)))
@@ -21,5 +23,5 @@ class Singleton(type):
 
     def __call__(cls, *args, **kwargs):
         if cls not in cls._instances:
-            cls._instances[cls] = super(Singleton, cls).__call__(*args, **kwargs)
+            cls._instances[cls] = super().__call__(*args, **kwargs)
         return cls._instances[cls]
